==> ikapi-2.1.7.tgz: package/src/Database/DDB/IKDBQueryBatchWrite.js <==
import IKDBBaseQuery from './IKDBBaseQuery';
//
export default class IKDBQueryBatchWrite extends IKDBBaseQuery {
  constructor() {
    super();
    this.putItems = [];
    this.deleteItems = [];
  }
  /*public methods*/
  setPutItems(items) { this.putItems = items; }
  setDeleteItems(items) { this.deleteItems = items; }
  //
  appendPutQuery(query) { this.putItems.push(query); }
  appendDeleteQuery(query) { this.deleteItems.push(query); }

  async run(dbManager) {
    const resp = await this.rawRun(dbManager);
    return (resp && resp.UnprocessedItems && Object.keys(resp.UnprocessedItems).length == 0); //evaluate success response
  }
  async rawRun(dbManager) {
    const query = this._rawQuery(dbManager.tableName);
    const localConsole = (dbManager.transaction ? dbManager.transaction.logger : console);
    localConsole.log('Batch writting items: ', query);
    const resp = await dbManager.connection.batchWriteItem(query).promise();
    localConsole.debug('Raw result: ', resp);
    return resp;
  }

  /*private methods*/
  _rawQuery(dbTableName) {
    return this._buildBatchWriteQuery(
      { ...super._rawQuery(null /*no table name, since this operation is multitable*/)}, dbTableName);
  }

  //Builds RequestItems
  _buildBatchWriteQuery(expression, dbTableName) {
    console.debug('Building batch write query..');
    //Check for required keys
    if (!expression.RequestItems) expression.RequestItems = {};
    if (!expression.RequestItems[dbTableName]) expression.RequestItems[dbTableName] = [];
    //Put ops
    expression = this.__buildPutItems(expression, dbTableName);
    //Delete ops
    expression = this.__buildDeleteItems(expression, dbTableName);
    return expression;
  }
  __buildPutItems(expression, dbTableName) {
    for (let item of this.putItems.slice(0,24)) {
      if (item instanceof IKDBBaseQuery) item = item._rawQuery(dbTableName, true);
      expression.RequestItems[dbTableName].push({PutRequest: {Item: item}});
    } return expression;
  }
  __buildDeleteItems(expression, dbTableName) {
    for (let item of this.deleteItems.splice(0, (24 - this.putItems.length))) {
      if (item instanceof IKDBBaseQuery) item = item._rawQuery(dbTableName, true);
      expression.RequestItems[dbTableName].push({DeleteRequest: item});
    } return expression;
  }
}

==> ikapi-2.6.6.tgz: package/src/Database/DDB/IKDBQueryBatchWrite.js <==
import IKDBBaseQuery from './IKDBBaseQuery';
//
export default class IKDBQueryBatchWrite extends IKDBBaseQuery {
  constructor() {
    super();
    this.putItems = [];
    this.deleteItems = [];
  }
  /*public methods*/
  setPutItems(items) { this.putItems = items; }
  setDeleteItems(items) { this.deleteItems = items; }
  //
  appendPutQuery(query) { this.putItems.push(query); }
  appendDeleteQuery(query) { this.deleteItems.push(query); }

  async run(dbManager) {
    const resp = await this.rawRun(dbManager);
    return (resp && resp.UnprocessedItems && Object.keys(resp.UnprocessedItems).length == 0); //evaluate success response
  }
  async rawRun(dbManager) {
    const query = this._rawQuery(dbManager.tableName);
    const localConsole = (dbManager.transaction ? dbManager.transaction.logger : console);
    localConsole.log('Batch writting items: ', query);
    const resp = await dbManager.connection.batchWriteItem(query).promise();
    // localConsole.debug('Raw result: ', resp);
    return resp;
  }

  /*private methods*/
  _rawQuery(dbTableName) {
    return this._buildBatchWriteQuery(
      { ...super._rawQuery(null /*no table name, since this operation is multitable*/)}, dbTableName);
  }

  //Builds RequestItems
  _buildBatchWriteQuery(expression, dbTableName) {
    // console.debug('Building batch write query..');
    //Check for required keys
    if (!expression.RequestItems) expression.RequestItems = {};
    if (!expression.RequestItems[dbTableName]) expression.RequestItems[dbTableName] = [];
    //Put ops
    expression = this.__buildPutItems(expression, dbTableName);
    //Delete ops
    expression = this.__buildDeleteItems(expression, dbTableName);
    return expression;
  }
  __buildPutItems(expression, dbTableName) {
    for (let item of this.putItems.slice(0,24)) {
      if (item instanceof IKDBBaseQuery) item = item._rawQuery(dbTableName, true);
      expression.RequestItems[dbTableName].push({PutRequest: {Item: item}});
    } return expression;
  }
  __buildDeleteItems(expression, dbTableName) {
    for (let item of this.deleteItems.splice(0, (24 - this.putItems.length))) {
      if (item instanceof IKDBBaseQuery) item = item._rawQuery(dbTableName, true);
      expression.RequestItems[dbTableName].push({DeleteRequest: item});
    } return expression;
  }
}
